Version 0.4.1
-------------

(bugfix release, released on August 21st, 2014)

- Fixed ``cosmic.client.ClientLoggingMixin`` so that the ``log`` value is JSON
  serializable and the headers are represented consistently by lists of tuples.
- Added CHANGES file
- Improved long_description for PyPI
